@@ -16,6 +16,14 @@ from .data_individu import DataIndividu
 from .mapping import MappingIndividu
 
 
+cattr.register_structure_hook(Disabilitas, Disabilitas.from_str)
+cattr.register_structure_hook(PenyakitDiderita, PenyakitDiderita.from_str)
+
+cattr.register_unstructure_hook(Disabilitas, Disabilitas.todict)
+cattr.register_unstructure_hook(FasilitasKesehatan, FasilitasKesehatan.todict)
+cattr.register_unstructure_hook(Penghasilan, Penghasilan.todict)
+cattr.register_unstructure_hook(PenyakitDiderita, PenyakitDiderita.todict)
+
 __all__ = [
     "DataIndividu",
     "Disabilitas",
@@ -37,6 +45,8 @@ def import_individu(
     mapping = mapping or MappingIndividu()
     click.echo(f"Membuka {filepath}")
     wb = load_workbook(filepath, read_only=True)
+    faileds: List[str] = list()
+    failed = 0
     trying = 0
     skipped = 0
     success = 0
@@ -53,7 +63,7 @@ def import_individu(
             skipped += 1
             continue
         click.echo(f"Mempersiapkan data nik {nik}")
-        data = mapping(
+        data = mapping.make_individu(
             wb=wb,
             row=row,
             individu_ws="Individu",
@@ -66,15 +76,17 @@ def import_individu(
             trying += 1
             res = sdgs.save_individu(individu=individu, rt=rt, rw=rw)
             if not res:
-                click.echo(f"Gagal menyimpan individu karena {res}")
+                click.echo(f"Gagal menyimpan individu {nik} karena {res}")
             else:
+                click.echo(f"Berhasil mengirim data {nik}")
                 success += 1
         except Exception as e:
-            click.echo(f"Gagal menyimpan individu karena {e}")
-    else:
-        click.echo("Tidak ada data yang diimport")
-        return
+            faileds.append(str(row))
+            click.echo(f"Gagal menyimpan individu {nik} karena {e}")
+            failed += 1
     click.echo(
-        f"Berhasil mengimport data individu sebanyak {success}"
-        f"Berhasil {success}\nMencoba {trying}\nDilewati{skipped}"
+        f"Berhasil : {success}\nMencoba : {trying}\n"
+        f"Dilewati : {skipped}\nError : {failed}"
     )
+    if faileds:
+        click.echo("Baris yang gagal : " + ",".join(faileds))
